@@ -14,7 +14,8 @@ TASK_DONE_LIST = (FAILURE, COMPLETE, STOPPED)
 
 import threading
 
-bar_suffix = '%(percent)d%% || %(eta)d seconds remaining || %(elapsed)d seconds elapsed'
+bar_suffix = "{desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} "
+one_hundred_percent = 100
 
 
 class Task:
@@ -28,6 +29,7 @@ class Task:
         self.callback = callback
         self.cache = None
         self._logs = {}
+        self.prints = []
         if self.callback:
             t = threading.Thread(target=self.callback_thread)
             t.start()
@@ -35,14 +37,16 @@ class Task:
             self.update()
             print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
 
-    def wait(self, show_progress=False):
+    def wait(self):
         if self.finished():
             return
-        with tqdm(desc=self.task_type, total=100,
-                  bar_format="{desc}: {percentage:.1f}%|{bar}| remaining: {remaining} || elapsed: {elapsed} ") as bar:
+        with tqdm(desc=self.task_type, total=one_hundred_percent,
+                  bar_format=bar_suffix) as bar:
             while not self.finished():
                 time.sleep(0.1)
-                bar.n = self.progress * 100
+                [bar.write(log) for log in self.prints]
+                self.prints = []
+                bar.n = self.progress * one_hundred_percent
                 bar.refresh()
             if self.task_state == FAILURE:
                 self.update(include_result=True)
@@ -50,7 +54,7 @@ class Task:
             if self.task_state == STOPPED:
                 print("Task has been stopped.")
                 return
-            bar.n = 100
+            bar.n = one_hundred_percent
 
     def callback_thread(self):
         self.get_result()
@@ -73,6 +77,8 @@ class Task:
             self.task_result = response["result"]
         if "metrics" in response:
             self._logs = response["metrics"]
+        if "print" in response:
+            self.prints = response["print"]
 
     def __str__(self):
         return str(self.get_result())
