@@ -4,6 +4,6 @@ from .predict import predict
 from .train import train
 from .common import api
 from .Dataset import Dataset
-from .Model import Model
-from .export import export
+from .Model import Model, NLPHFModel, nlp_constructor
+from .export import export, export_task_result
 from .DataLoader import DataLoader
