@@ -11,7 +11,7 @@ from .Model import Model
 from .DataLoader import DataLoader
 from .Dataset import Dataset
 from .Task import Task, bar_suffix
-from .saving.saving import save_data, determine_model
+from .saving.saving import save_data, determine_model, TF_str, mxnet_str, pytorch_str
 from .web.urls import TOKEN_URL, HASH_URL, UPLOAD_DATA_URL
 
 VERBOSITY = 1
@@ -261,12 +261,12 @@ def validate_model(model, data):
     if isinstance(data, str):
         return
     # data = convert_to_numpy(data)
-    if library == "pytorch":
+    if library == pytorch_str:
         from torch import ones
-    elif library == "mxnet":
+    elif library == mxnet_str:
         from mxnet import nd
         ones = nd.ones
-    elif library == "TF":
+    elif library == TF_str:
         from numpy import ones
     else:
         return
