@@ -6,6 +6,10 @@ from io import BytesIO
 
 import numpy as np
 
+pytorch_str = "pytorch"
+mxnet_str =  "mxnet"
+TF_str = "TF"
+
 
 def convert_to_numpy(data):
     if isinstance(data, (tuple, list)):
@@ -17,10 +21,11 @@ def convert_to_numpy(data):
 def save_model(model, library: str):
     model_path = model
     if not isinstance(model, str):
+        #     with tempfile.TemporaryDirectory() as t_dir:
         if not os.path.isdir("tmp"):
             os.mkdir("tmp")
         model_path = "tmp/tmp_model"
-        if library == "pytorch":
+        if library == pytorch_str:
             from torch import save
             import dill
             model_path += ".pt"
@@ -30,7 +35,7 @@ def save_model(model, library: str):
             import keras
             with keras.backend.get_session().graph.as_default():
                 model.save_model(model_path)
-        elif library == "mxnet":
+        elif library == mxnet_str:
             model_path += ".tar"
             model.export(model_path)
             with tarfile.open(model_path, "w") as tar:
@@ -38,7 +43,7 @@ def save_model(model, library: str):
                 paramname = model_path + "-0000.params"
                 tar.add(jsonname, arcname=os.path.basename(jsonname))
                 tar.add(paramname, arcname=os.path.basename(paramname))
-        elif library == "TF":
+        elif library == TF_str:
             model_path += ".tar"
             model.save(model_path + "dir")
             # save_model(model, model_path + "dir", include_optimizer=True, save_format='tf')
@@ -52,7 +57,7 @@ def save_model(model, library: str):
     return model_path
 
     # if model_type is ModelType.ONNX:
-    #     onnx.save(model, file_path)
+    #     onnx.save(model, file)
     # elif model_type is ModelType.TF1:
     #     pass
     # tf.saved_model.save(model, "./dd.pb")
@@ -133,22 +138,22 @@ def determine_model(model):
     try:
         from torch.nn import Module
         if isinstance(model, Module):
-            return "pytorch"
+            return pytorch_str
     except:
         pass
     try:
         from tensorflow.keras import Model
         if isinstance(model, Model):
-            return "TF"
+            return TF_str
     except:
         pass
     try:
         from mxnet.gluon.nn import Block
         if isinstance(model, Block):
-            return "mxnet"
+            return mxnet_str
     except:
         pass
     if isinstance(model, str):
         if model.endswith(".pt"):
-            return "pytorch"
+            return pytorch_str
     raise ValueError("Could not determine framework model is from. Please specify explicitly.")
