@@ -18,7 +18,7 @@ def train(model, train_data, val_data, batch_size, epochs, optimiser, loss, metr
     task = Task(trainApi(model, train_data, val_data, batch_size, epochs, optimiser, loss, metrics, trained_model_name,
                          task_id, **kwargs).json(), callback)
     if not asynchronous:
-        task.wait(show_progress=True)
+        task.wait()
         print("Model finished training")
     return task
 
