@@ -7,17 +7,17 @@ Accuracy = "Accuracy"
 # Binary_accuracy = "Binary_accuracy"
 # Binary_cross_entropy = "Binary_cross_entropy"
 # Categorical_accuracy = "Categorical_accuracy"
-Categorical_cross_entropy = "Categorical_cross_entropy"
+CategoricalCrossEntropy = "Categorical_cross_entropy"
 # Categorical_hinge = "Categorical_hinge"
 # Cosine_similarity = "Cosine_similarity"
 # Hinge = "Hinge"
 # Kl_divergence = "Kl_divergence"
 # Log_cosh_error = "Log_cosh_error"
 # Mean = "Mean"
-Mean_absolute_error = "Mean_absolute_error"
+MeanAbsoluteError = "Mean_absolute_error"
 # Mean_absolute_percentage_error = "Mean_absolute_percentage_error"
 # Mean_relative_error = "Mean_relative_error"
-Mean_squared_error = "Mean_squared_error"
+MeanSquaredError = "Mean_squared_error"
 # Mean_squared_logarithmic_error = "Mean_squared_logarithmic_error"
 # Mean_tensor = "Mean_tensor"
 # Poisson = "Poisson"
