@@ -97,7 +97,7 @@ def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.S
                       asynchronous, callback, **kwargs)
 
 
-def export(model, path="."):
+def export(model, path=".", as_object=True, save_to_disk=True):
     """Export a model to file. This will export it in the original format it is in. Global models will be exported as
     pytorch models.
 
@@ -105,9 +105,26 @@ def export(model, path="."):
         :type model: From :func:`npu.compile` or :func:`npu.train`. Id (str) or global :class:`npu.vision.models.Model` can be used.
         :param path: Path to where the model is saved to. Default is ".".
         :type path: str, optional
+        :param as_object: If you wish to return the object back as an object in memory as a model in the respective framework
+        :type as_object: bool, optional
+        :param save_to_disk: By default, we always flush the file to disk. Set this to False to prevent flushing. Will
+        also return the file as a file obj **only** if as_object is False.
+        :type save_to_disk: bool, optional
+
     """
-    return core.export(model, path)
+    return core.export(model, path, as_object, save_to_disk)
 
 
+def export_task_result(task):
+    """Export a Task to memory. Will generically work on all task types. Predictions return the explicit results,
+    training/compile returns ids
+
+        :param task: Task to export
+        :type task: From :func:`npu.compile` or :func:`npu.train`. Id (str) or global :class:`npu.vision.models.Model` can be used.
+    """
+    return core.export_task_result(task)
 
 
+def print(_):
+    pass
+
