@@ -36,23 +36,26 @@ def RMS(lr=0.001, decay=0):
         }}
 
 
-def Adam(lr=0.001):#, beta1=0.9, beta2=0.999, epsilon=1e-08):
+def Adam(lr=0.001, weight_decay=0):  # , beta1=0.9, beta2=0.999, epsilon=1e-08):
     """Adam Optimiser.
 
               :param lr: Learning rate
               :type lr: float
-              :param beta1: Beta 1
-              :type beta1: float
-              :param beta2: Beta 2
-              :type beta2: float
-              :param epsilon: Epsilon
-              :type epsilon: float
+              :param weight_decay: Weight decay
+              :type weight_decay: float, optional
+              # :param beta1: Beta 1
+              # :type beta1: float
+              # :param beta2: Beta 2
+              # :type beta2: float
+              # :param epsilon: Epsilon
+              # :type epsilon: float
           """
     return {
         "optimiser": "Adam",
         "opt_args": {
-            "lr": lr
-#             "beta1": beta1,
-#             "beta2": beta2,
-#             "epsilon": epsilon,
+            "lr": lr,
+            "weight_decay": weight_decay
+            #             "beta1": beta1,
+            #             "beta2": beta2,
+            #             "epsilon": epsilon,
         }}
